// DATA ANAYLSIS: AHL Survey Germany
// Authors: Carolin Kilian, Moritz Liebig
// Date: 03/18/2024

// Load data
xmluse "/Users/carolinkilian/Desktop/AHL Survey Deutschland/RohdatenAHL.xml", clear // LimeSurvey exportiert den Fragebogen nur im XML-Format, Dateipfad mit in do-file kopieren

// Data cleaning 

drop submitdate
drop lastpage
drop seed
drop startlanguage

* 1) age restriction
capture drop agegroup
drop if f1<18 // n = 2
gen agegroup = f1
recode agegroup (18/34=1)(35/49=2)(50/100=3)
label define age1 1 "18-34" 2 "35-49" 3 "50+", replace
label values agegroup age1
label variable age "Age groups"
rename f1 age 

* 2) dependent variable: AHL score

*f21, drop missing data and calculate sumscore for question on alcohol-related diseases
*drop if f21_99 == 1 // n = 3

recode f21_1 (2=0)
rename f21_1 alc_cancer

recode f21_2 (2=0)
rename f21_2 alc_mental

recode f21_3 (2=0)
rename f21_3 alc_liver

recode f21_4 (2=0)
rename f21_4 alc_infection

recode f21_5 (2=0)
rename f21_5 alc_heart

recode f21_6 (2=0)
rename f21_6 alc_injury

recode f21_7 (2=0)
rename f21_7 alc_dementia

recode f21_8 (2=0)
rename f21_8 alc_fetal

recode f21_9 (2=0)
rename f21_9 alc_respiratory

gen alc_diseases = alc_cancer + alc_mental + alc_liver + alc_infection + alc_heart + alc_injury + alc_dementia + alc_fetal + alc_respiratory 
gen alc_diseases_detail = alc_diseases
recode alc_diseases (0/5=1) (6/7=2) (8=3) (9=4)
replace alc_diseases = . if f21_99 == 1
replace alc_diseases = 1 if f21_10 == 1 // all who agreed with F21_10 to get 1 point

*f22, recode variable and drop missing or implausible data
replace f22="1" if f22=="-oth-" 
replace f22="2" if f22=="99"
destring, replace

*drop if f22==2 // n = 20
*drop f22 
*drop if f22_other >20 // n = 3

gen maxalc_pregnancy = f22_other
gen maxalc_preg_detail = maxalc_pregnancy
recode maxalc_pregnancy (0=4) (0.00000001/20=1)
replace maxalc_pregnancy = . if f22_other >20
tab maxalc_pregnancy, mis // n = 24

*f2mat, drop missing data
*drop if f2mat_f23==99 // n = 3
*drop if f2mat_f24==99 // n = 36
*drop if f2mat_f25==99 // n = 15
*drop if f2mat_f26==99 // n = 64
*drop if f2mat_f27==99 // n = 2
recode f2mat_f23 (99=.) // n = 3
rename f2mat_f23 health_risk

recode f2mat_f24 (99=.) // n = 36
rename f2mat_f24 cancer_risk

recode f2mat_f25 (99=.) // n = 15
rename f2mat_f25 wine_health

recode f2mat_f26 (99=.) // n = 64
rename f2mat_f26 wine_beer_health

recode f2mat_f27 (99=.) // n = 4
rename f2mat_f27 risk_knowledge

*f28, drop missing data and recode
*drop if f28==99 // n = 10
*drop if f282==99 // n = 1
recode f28 (99=.) // n = 18
recode f282 (1=4) (2=3) (3=2) (4=1) (.=1) (99=.)
rename f282 understand_health_info
label val understand_health_info

*f29, drop missing data and recode 
replace f29="1" if f29=="-oth-" 
replace f29="2" if f29=="99"
destring, replace

*drop if f29==2 // n = 13
*drop f29
*drop if f29_other >100

capture drop maxalc_men
gen maxalc_men = f29_other
gen maxalc_men_detail = maxalc_men
recode maxalc_men (2=4) (2.0001/100=1) (0/1.99999=1)
replace maxalc_men =. if maxalc_men > 100 // n = 2
replace maxalc_men =. if f29 == 2 // n = 0

*f210, rop missing data and recode 
replace f210="1" if f210=="-oth-"
replace f210="2" if f210=="99"
destring, replace

*drop if f210==2 // n = 2
*drop f210 
*drop if f210_other >100 // n = 1

capture drop maxalc_women
gen maxalc_women= f210_other
gen maxalc_women_detail = maxalc_women
recode maxalc_women (1=4) (1.0001/1000000000000000000000000000000000000000000000000000=1) (0/0.99999=1)
replace maxalc_women =. if maxalc_women > 100 // n = 0
replace maxalc_women =. if f210 == 2 // n = 30

*calculate AHL score
recode wine_health (1=4) (2=3) (3=2) (4=1) 
recode wine_beer_health (1=4) (2=3) (3=2) (4=1) 

capture drop ahlscore
gen ahlscore = (alc_diseases + maxalc_pregnancy + maxalc_men + maxalc_women + health_risk + cancer_risk + wine_health + wine_beer_health + understand_health_info)  /9  // missings: n = 162

recode ahlscore (1/3=1) (3.0000000000000000001/4=0) 
label define ahlscore1 2 "missing" 1 "inadequate AHL" 0 "adequate AHL", replace
label values ahlscore ahlscore1
label variable ahlscore "AHL Score"
tab ahlscore, mis

gen ahlscore_mis = ahlscore
recode ahlscore_mis (.=2) (1/3=1) (3.0000000000000000001/4=0) 
label values ahlscore_mis ahlscore1
label variable ahlscore_mis "AHL Score with missings"
tab ahlscore_mis, mis

* 3) Independent variable: educational attainment 
 
*ISCED
capture drop schulbildung
drop if f42 == 99 // n = 0 
gen schulbildung = f42
tab schulbildung, nolab
recode schulbildung (1/6=1) (7/8=10) (9/10=1)
label define schulbildung1 1 "kein Abi oder FHR" 10 "Abi oder FHR", replace
label values schulbildung schulbildung1
drop f42 // nicht mehr benötigt
label variable schulbildung "Education (school)"

capture drop bg
drop if f44==99 // n = 20
gen bg = f44
tab bg, nolabel
recode bg (7/9=100) (5/6=10) (1/4=1) (10=1)
label define bg1 100 "high" 10 "middle" 1 "low", replace
label values bg bg1
label variable bg "Education (occupational)"
drop f44

capture drop education
generate education = bg + schulbildung
tab education
recode education (2=1) (10/20=2) (100/200=3)
label define bildung1 1 "low" 2 "middle" 3 "high", replace
label values education bildung1
label variable education "Educational attainment"

* 4) Covariates: gender

capture drop gender
gen gender = f41
drop if gender==99 // n = 5
drop if gender==3 // n = 5
recode gender (1=0) (2=1)
label define gender1 0 "women" 1 "men", replace
label values gender gender1
label variable gender "Sex/gender"
drop f41

* 5) Covariates: AUDIT-C

*drop missing data
drop if f11==99 // n = 0
drop if f12==99 // n = 1
drop if f12d==6 // n = 1 
drop if f13==99 // n = 0
drop if f13d==99 // n = 0

*rescaling
tab f11, nolab
recode f11 (1=0) (2=1) (3=2) (4=3) (5=4) (.=0) 
label values f11 .

tab f12, nolab
recode f12 (1=0) (2=1) (3=2) (4=3) (5=4) (.=0)
label values f12 .

tab f12d, nolab
recode f12d (1=0) (2=1) (3=2) (4=3) (5=4) (.=0)
label values f12d .

tab f13, nolab
recode f13 (1=0) (2=1) (3=2) (4=3) (5=4) (.=0)
label values f13 .

tab f13d, nolab
recode f13d (1=0) (2=1) (3=2) (4=3) (5=4) (.=0)
label values f13d .

capture drop f12neu // combine smartphone and desktop versions
gen f12neu = f12 + f12d
drop f12 
drop f12d
rename f12neu f12
label variable f12 "Drinking quantity"

capture drop f13neu // combine smartphone and desktop versions
gen f13neu = f13 + f13d
drop f13 
drop f13d
rename f13neu f13
label variable f13 "HED drinking"

*compute AUDIT-C score
capture drop auditc
gen auditc=f11 + f12 + f13 //alle Audit vars aufsummiert
label variable auditc "AUDIT-C score"

gen auditc_3 = auditc
recode auditc_3 (0=1) (1/3=2) (4/12=3) if gender == 0
recode auditc_3 (0=1) (1/4=2) (5/12=3) if gender == 1
label define auditc1 1 "abstainer" 2 "low risk" 3 "high risk", replace
label values auditc_3 auditc1
label variable auditc_3 "AUDIT-C score (dichotomised)"

* 6) Covariates: general health literacz (HLS-EU-Q6)

*drop missing data
drop if f3mat_f31==99 // n = 6
rename f3mat_f31 hls01

drop if f3mat_f32==99 // n = 14
rename f3mat_f32 hls02

drop if f3mat_f33==99 // n = 13
rename f3mat_f33 hls03

drop if f3mat_f34==99 // n = 2
rename f3mat_f34 hls04

drop if f3mat_f35==99 // n = 3
rename f3mat_f35 hls05

drop if f3mat_f36==99 // n = 4
rename f3mat_f36 hls06

*recode variables
recode hls01 (1=4) (2=3) (3=2) (4=1)
recode hls02 (1=4) (2=3) (3=2) (4=1)
recode hls03 (1=4) (2=3) (3=2) (4=1)
recode hls04 (1=4) (2=3) (3=2) (4=1)
recode hls05 (1=4) (2=3) (3=2) (4=1)
recode hls06 (1=4) (2=3) (3=2) (4=1)

*compute HLS-EU-Q6 score
capture drop hlsscore
gen hlsscore = (hls01 + hls02 + hls03 + hls04 + hls05 + hls06)  /6
recode hlsscore (1/2=1) (2.0000000000000000001/3=2) (3.0000000000000000001/4=3) 
label define hlsscore1 1 "inadequate HL" 2 "problematic HL" 3 "sufficent HL", replace
label values hlsscore hlsscore1
ta hlsscore
label variable hlsscore "HLS-EU-Q6 Score"

// Basic descriptives

tab gender if !missing(ahlscore)
sort gender
by gender: sum age if !missing(ahlscore)

// Save output 
drop id f0 f3 f11 f12 f13 f14 f21_99 f22 f28 f29 f21_10 f210 f210_other f22_other f29_other f43 f45 f45_other f46 f47 f47_other f48 f48_other schulbildung bg
order gender age agegroup education auditc auditc_3 ///
	  alc_cancer alc_mental alc_liver alc_infection alc_heart alc_injury alc_dementia alc_fetal alc_respiratory alc_diseases alc_diseases_detail ///
	  health_risk cancer_risk wine_health wine_beer_health risk_knowledge understand_health_info ///
	  maxalc_pregnancy maxalc_preg_detail maxalc_women maxalc_women_detail maxalc_men maxalc_men_detail ahlscore ahlscore_mis ///
	  hls01 hls02 hls03 hls04 hls05 hls06 hlsscore

outsheet using "/Users/carolinkilian/Desktop/AHL Survey Deutschland/20240521_AHL_data_clean.csv", comma nolabel replace
